import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppServiceEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#allowed_user_ip_cidrs AppServiceEnvironment#allowed_user_ip_cidrs}.
     *
     * @stability stable
     */
    readonly allowedUserIpCidrs?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#front_end_scale_factor AppServiceEnvironment#front_end_scale_factor}.
     *
     * @stability stable
     */
    readonly frontEndScaleFactor?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#internal_load_balancing_mode AppServiceEnvironment#internal_load_balancing_mode}.
     *
     * @stability stable
     */
    readonly internalLoadBalancingMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#name AppServiceEnvironment#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#pricing_tier AppServiceEnvironment#pricing_tier}.
     *
     * @stability stable
     */
    readonly pricingTier?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#resource_group_name AppServiceEnvironment#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#subnet_id AppServiceEnvironment#subnet_id}.
     *
     * @stability stable
     */
    readonly subnetId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#tags AppServiceEnvironment#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#user_whitelisted_ip_ranges AppServiceEnvironment#user_whitelisted_ip_ranges}.
     *
     * @stability stable
     */
    readonly userWhitelistedIpRanges?: string[];
    /**
     * cluster_setting block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#cluster_setting AppServiceEnvironment#cluster_setting}
     *
     * @stability stable
     */
    readonly clusterSetting?: AppServiceEnvironmentClusterSetting[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#timeouts AppServiceEnvironment#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: AppServiceEnvironmentTimeouts;
}
/**
 * @stability stable
 */
export interface AppServiceEnvironmentClusterSetting {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#name AppServiceEnvironment#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#value AppServiceEnvironment#value}.
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface AppServiceEnvironmentTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#create AppServiceEnvironment#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#delete AppServiceEnvironment#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#read AppServiceEnvironment#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html#update AppServiceEnvironment#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html azurerm_app_service_environment}.
 *
 * @stability stable
 */
export declare class AppServiceEnvironment extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/app_service_environment.html azurerm_app_service_environment} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppServiceEnvironmentConfig);
    private _allowedUserIpCidrs?;
    /**
     * @stability stable
     */
    get allowedUserIpCidrs(): string[];
    /**
     * @stability stable
     */
    set allowedUserIpCidrs(value: string[]);
    /**
     * @stability stable
     */
    resetAllowedUserIpCidrs(): void;
    /**
     * @stability stable
     */
    get allowedUserIpCidrsInput(): string[] | undefined;
    private _frontEndScaleFactor?;
    /**
     * @stability stable
     */
    get frontEndScaleFactor(): number;
    /**
     * @stability stable
     */
    set frontEndScaleFactor(value: number);
    /**
     * @stability stable
     */
    resetFrontEndScaleFactor(): void;
    /**
     * @stability stable
     */
    get frontEndScaleFactorInput(): number | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _internalLoadBalancingMode?;
    /**
     * @stability stable
     */
    get internalLoadBalancingMode(): string;
    /**
     * @stability stable
     */
    set internalLoadBalancingMode(value: string);
    /**
     * @stability stable
     */
    resetInternalLoadBalancingMode(): void;
    /**
     * @stability stable
     */
    get internalLoadBalancingModeInput(): string | undefined;
    /**
     * @stability stable
     */
    get location(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _pricingTier?;
    /**
     * @stability stable
     */
    get pricingTier(): string;
    /**
     * @stability stable
     */
    set pricingTier(value: string);
    /**
     * @stability stable
     */
    resetPricingTier(): void;
    /**
     * @stability stable
     */
    get pricingTierInput(): string | undefined;
    private _resourceGroupName?;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    resetResourceGroupName(): void;
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string | undefined;
    private _subnetId;
    /**
     * @stability stable
     */
    get subnetId(): string;
    /**
     * @stability stable
     */
    set subnetId(value: string);
    /**
     * @stability stable
     */
    get subnetIdInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _userWhitelistedIpRanges?;
    /**
     * @stability stable
     */
    get userWhitelistedIpRanges(): string[];
    /**
     * @stability stable
     */
    set userWhitelistedIpRanges(value: string[]);
    /**
     * @stability stable
     */
    resetUserWhitelistedIpRanges(): void;
    /**
     * @stability stable
     */
    get userWhitelistedIpRangesInput(): string[] | undefined;
    private _clusterSetting?;
    /**
     * @stability stable
     */
    get clusterSetting(): AppServiceEnvironmentClusterSetting[];
    /**
     * @stability stable
     */
    set clusterSetting(value: AppServiceEnvironmentClusterSetting[]);
    /**
     * @stability stable
     */
    resetClusterSetting(): void;
    /**
     * @stability stable
     */
    get clusterSettingInput(): AppServiceEnvironmentClusterSetting[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AppServiceEnvironmentTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AppServiceEnvironmentTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AppServiceEnvironmentTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
