import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ImageConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#hyper_v_generation Image#hyper_v_generation}.
     *
     * @stability stable
     */
    readonly hyperVGeneration?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#location Image#location}.
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#name Image#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#resource_group_name Image#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#source_virtual_machine_id Image#source_virtual_machine_id}.
     *
     * @stability stable
     */
    readonly sourceVirtualMachineId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#tags Image#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#zone_resilient Image#zone_resilient}.
     *
     * @stability stable
     */
    readonly zoneResilient?: boolean;
    /**
     * data_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#data_disk Image#data_disk}
     *
     * @stability stable
     */
    readonly dataDisk?: ImageDataDisk[];
    /**
     * os_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#os_disk Image#os_disk}
     *
     * @stability stable
     */
    readonly osDisk?: ImageOsDisk[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#timeouts Image#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ImageTimeouts;
}
/**
 * @stability stable
 */
export interface ImageDataDisk {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#blob_uri Image#blob_uri}.
     *
     * @stability stable
     */
    readonly blobUri?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#caching Image#caching}.
     *
     * @stability stable
     */
    readonly caching?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#lun Image#lun}.
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#managed_disk_id Image#managed_disk_id}.
     *
     * @stability stable
     */
    readonly managedDiskId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#size_gb Image#size_gb}.
     *
     * @stability stable
     */
    readonly sizeGb?: number;
}
/**
 * @stability stable
 */
export interface ImageOsDisk {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#blob_uri Image#blob_uri}.
     *
     * @stability stable
     */
    readonly blobUri?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#caching Image#caching}.
     *
     * @stability stable
     */
    readonly caching?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#managed_disk_id Image#managed_disk_id}.
     *
     * @stability stable
     */
    readonly managedDiskId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#os_state Image#os_state}.
     *
     * @stability stable
     */
    readonly osState?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#os_type Image#os_type}.
     *
     * @stability stable
     */
    readonly osType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#size_gb Image#size_gb}.
     *
     * @stability stable
     */
    readonly sizeGb?: number;
}
/**
 * @stability stable
 */
export interface ImageTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#create Image#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#delete Image#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#read Image#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/image.html#update Image#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/image.html azurerm_image}.
 *
 * @stability stable
 */
export declare class Image extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/image.html azurerm_image} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ImageConfig);
    private _hyperVGeneration?;
    /**
     * @stability stable
     */
    get hyperVGeneration(): string;
    /**
     * @stability stable
     */
    set hyperVGeneration(value: string);
    /**
     * @stability stable
     */
    resetHyperVGeneration(): void;
    /**
     * @stability stable
     */
    get hyperVGenerationInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _sourceVirtualMachineId?;
    /**
     * @stability stable
     */
    get sourceVirtualMachineId(): string;
    /**
     * @stability stable
     */
    set sourceVirtualMachineId(value: string);
    /**
     * @stability stable
     */
    resetSourceVirtualMachineId(): void;
    /**
     * @stability stable
     */
    get sourceVirtualMachineIdInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zoneResilient?;
    /**
     * @stability stable
     */
    get zoneResilient(): boolean;
    /**
     * @stability stable
     */
    set zoneResilient(value: boolean);
    /**
     * @stability stable
     */
    resetZoneResilient(): void;
    /**
     * @stability stable
     */
    get zoneResilientInput(): boolean | undefined;
    private _dataDisk?;
    /**
     * @stability stable
     */
    get dataDisk(): ImageDataDisk[];
    /**
     * @stability stable
     */
    set dataDisk(value: ImageDataDisk[]);
    /**
     * @stability stable
     */
    resetDataDisk(): void;
    /**
     * @stability stable
     */
    get dataDiskInput(): ImageDataDisk[] | undefined;
    private _osDisk?;
    /**
     * @stability stable
     */
    get osDisk(): ImageOsDisk[];
    /**
     * @stability stable
     */
    set osDisk(value: ImageOsDisk[]);
    /**
     * @stability stable
     */
    resetOsDisk(): void;
    /**
     * @stability stable
     */
    get osDiskInput(): ImageOsDisk[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ImageTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ImageTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ImageTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
