import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SpringCloudAppConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#https_only SpringCloudApp#https_only}.
     *
     * @stability stable
     */
    readonly httpsOnly?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#is_public SpringCloudApp#is_public}.
     *
     * @stability stable
     */
    readonly isPublic?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#name SpringCloudApp#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#resource_group_name SpringCloudApp#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#service_name SpringCloudApp#service_name}.
     *
     * @stability stable
     */
    readonly serviceName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#tls_enabled SpringCloudApp#tls_enabled}.
     *
     * @stability stable
     */
    readonly tlsEnabled?: boolean;
    /**
     * identity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#identity SpringCloudApp#identity}
     *
     * @stability stable
     */
    readonly identity?: SpringCloudAppIdentity[];
    /**
     * persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#persistent_disk SpringCloudApp#persistent_disk}
     *
     * @stability stable
     */
    readonly persistentDisk?: SpringCloudAppPersistentDisk[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#timeouts SpringCloudApp#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: SpringCloudAppTimeouts;
}
/**
 * @stability stable
 */
export interface SpringCloudAppIdentity {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#type SpringCloudApp#type}.
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface SpringCloudAppPersistentDisk {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#mount_path SpringCloudApp#mount_path}.
     *
     * @stability stable
     */
    readonly mountPath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#size_in_gb SpringCloudApp#size_in_gb}.
     *
     * @stability stable
     */
    readonly sizeInGb: number;
}
/**
 * @stability stable
 */
export interface SpringCloudAppTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#create SpringCloudApp#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#delete SpringCloudApp#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#read SpringCloudApp#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html#update SpringCloudApp#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html azurerm_spring_cloud_app}.
 *
 * @stability stable
 */
export declare class SpringCloudApp extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/spring_cloud_app.html azurerm_spring_cloud_app} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SpringCloudAppConfig);
    /**
     * @stability stable
     */
    get fqdn(): string;
    private _httpsOnly?;
    /**
     * @stability stable
     */
    get httpsOnly(): boolean;
    /**
     * @stability stable
     */
    set httpsOnly(value: boolean);
    /**
     * @stability stable
     */
    resetHttpsOnly(): void;
    /**
     * @stability stable
     */
    get httpsOnlyInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _isPublic?;
    /**
     * @stability stable
     */
    get isPublic(): boolean;
    /**
     * @stability stable
     */
    set isPublic(value: boolean);
    /**
     * @stability stable
     */
    resetIsPublic(): void;
    /**
     * @stability stable
     */
    get isPublicInput(): boolean | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _serviceName;
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    set serviceName(value: string);
    /**
     * @stability stable
     */
    get serviceNameInput(): string;
    private _tlsEnabled?;
    /**
     * @stability stable
     */
    get tlsEnabled(): boolean;
    /**
     * @stability stable
     */
    set tlsEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetTlsEnabled(): void;
    /**
     * @stability stable
     */
    get tlsEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get url(): string;
    private _identity?;
    /**
     * @stability stable
     */
    get identity(): SpringCloudAppIdentity[];
    /**
     * @stability stable
     */
    set identity(value: SpringCloudAppIdentity[]);
    /**
     * @stability stable
     */
    resetIdentity(): void;
    /**
     * @stability stable
     */
    get identityInput(): SpringCloudAppIdentity[] | undefined;
    private _persistentDisk?;
    /**
     * @stability stable
     */
    get persistentDisk(): SpringCloudAppPersistentDisk[];
    /**
     * @stability stable
     */
    set persistentDisk(value: SpringCloudAppPersistentDisk[]);
    /**
     * @stability stable
     */
    resetPersistentDisk(): void;
    /**
     * @stability stable
     */
    get persistentDiskInput(): SpringCloudAppPersistentDisk[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): SpringCloudAppTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: SpringCloudAppTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SpringCloudAppTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
